/* config.h.  Generated from config.h.in by configure.  */
/* config.h.in.  Generated from configure.in by autoheader.  */

/*
 * needed for auto configuration
 * $Id: acconfig.h,v 1.1.1.1 1996/06/06 19:41:05 fp Exp $
 */

/*
 * If your system is kinda special
 */
/* #undef SYSTEM_DOS */
/* #undef SYSTEM_QUICKWIN */
/* #undef SYSTEM_WINDLL */
/* #undef SYSTEM_OS2 */

/*
 * If your system has stdin/stdout/stderr
 */
/* #undef HAVE_STDIO */

/*
 * how to declare functions that are exported from the UU library
 */
#define UUEXPORT /**/

/*
 * how to declare functions that are exported from the UUTCL library
 */
#define UUTCLEXPORT /**/

/*
 * how to declare functions that are exported from the fptools library
 */
#define TOOLEXPORT /**/

/*
 * how to declare functions that are interfaced with TCL
 */
#define UUTCLFUNC /**/

/*
 * define if your compiler supports function prototypes
 */
#define PROTOTYPES 1

/*
 * define if you have TCL version 7.5 or later
 */
/* #undef HAVE_TCL */

/* 
 * define if you HAVE_TCL and TK version 4.1 or later 
 */
/* #undef HAVE_TK */

/*
 * define if your Tk can handle the Tk_CreatePhotoImageFormat hook 
 */
/* #undef TK_PHOTO */

/*
 * define if Tcl_Main or Tk_Main needs Tcl_AppInit as third parameter 
 */
/* #undef TMAIN_THREE */

/*
 * Replacement functions.
 * #define strerror _FP_strerror
 * #define tempnam  _FP_tempnam
 * if you don't have these functions
 */
/* #undef strerror */
/* #undef tempnam */

/*
 * your system's directory separator (usually "/")
 */
#define DIRSEPARATOR "/"

/* 
 * your mailing program. full path and the necessary parameters.
 * the recipient address is added to the command line (with a leading
 * space) without any further options
 */
/* #undef PROG_MAILER */

/* 
 * define if the mailer needs to have the subject set on the command
 * line with -s "Subject". Preferredly, we send the subject as a header.
 */
/* #undef MAILER_NEEDS_SUBJECT */

/* 
 * define if posting is enabled. Do not edit.
 */
#define HAVE_NEWS 1

/*
 * your local news posting program. full path and parameters, so that
 * the article and all its headers are read from stdin
 */
#define PROG_INEWS "/usr/bin/minews -h"

/*
 * the name of your local domain. only needed when using minews
 */
#define DOMAINNAME "lan"

/* 
 * your local NNTP news server. only needed when using minews
 * can be overridden by $NNTPSERVER at runtime
 */
/* #undef NNTPSERVER */

/*
 * defined when we use minews, so that we know that we must define
 * the NNTPSERVER environment variable to be able to post
 */
#define NEED_NNTPSERVER 1

/*
 * whether you want to hide your hostname behind the domain. usually
 * undefined
 */
/* #undef HIDDENNET */


/* Define to 1 if you have the <direct.h> header file. */
/* #undef HAVE_DIRECT_H */

/* Define to 1 if you have the <errno.h> header file. */
#define HAVE_ERRNO_H 1

/* Define to 1 if you have the <fcntl.h> header file. */
#define HAVE_FCNTL_H 1

/* Define to 1 if you have the 'getcwd' function. */
#define HAVE_GETCWD 1

/* Define to 1 if you have the 'gettimeofday' function. */
#define HAVE_GETTIMEOFDAY 1

/* Define to 1 if you have the <inttypes.h> header file. */
#define HAVE_INTTYPES_H 1

/* Define to 1 if you have the <io.h> header file. */
/* #undef HAVE_IO_H */

/* Define to 1 if you have the 'isatty' function. */
#define HAVE_ISATTY 1

/* Define to 1 if you have the <malloc.h> header file. */
#define HAVE_MALLOC_H 1

/* Define to 1 if you have the <memory.h> header file. */
#define HAVE_MEMORY_H 1

/* Define to 1 if you have the 'popen' function. */
#define HAVE_POPEN 1

/* Define to 1 if you have the <pwd.h> header file. */
#define HAVE_PWD_H 1

/* Define to 1 if you have the <stdint.h> header file. */
#define HAVE_STDINT_H 1

/* Define to 1 if you have the <stdio.h> header file. */
#define HAVE_STDIO_H 1

/* Define to 1 if you have the <stdlib.h> header file. */
#define HAVE_STDLIB_H 1

/* Define to 1 if you have the <strings.h> header file. */
#define HAVE_STRINGS_H 1

/* Define to 1 if you have the <string.h> header file. */
#define HAVE_STRING_H 1

/* Define to 1 if you have the <sys/stat.h> header file. */
#define HAVE_SYS_STAT_H 1

/* Define to 1 if you have the <sys/time.h> header file. */
#define HAVE_SYS_TIME_H 1

/* Define to 1 if you have the <sys/types.h> header file. */
#define HAVE_SYS_TYPES_H 1

/* Define to 1 if you have the <unistd.h> header file. */
#define HAVE_UNISTD_H 1

/* Define to the address where bug reports for this package should be sent. */
#define PACKAGE_BUGREPORT ""

/* Define to the full name of this package. */
#define PACKAGE_NAME ""

/* Define to the full name and version of this package. */
#define PACKAGE_STRING ""

/* Define to the one symbol short name of this package. */
#define PACKAGE_TARNAME ""

/* Define to the home page for this package. */
#define PACKAGE_URL ""

/* Define to the version of this package. */
#define PACKAGE_VERSION ""

/* Define to 1 if all of the C89 standard headers exist (not just the ones
   required in a freestanding environment). This macro is provided for
   backward compatibility; new code need not use it. */
#define STDC_HEADERS 1

/* Define to 1 if you can safely include both <sys/time.h> and <time.h>. This
   macro is obsolete. */
#define TIME_WITH_SYS_TIME 1

/* Define as 'unsigned int' if <stddef.h> doesn't define. */
/* #undef size_t */
